@@ -4,8 +4,8 @@ import os
 import socket
 from sys import version_info
 
+from .embedded_server.openssh import OpenSSHServer
 from ssh2.session import Session
-from embedded_server.openssh import OpenSSHServer
 
 
 PKEY_FILENAME = os.path.sep.join([os.path.dirname(__file__), 'unit_test_key'])
@@ -46,5 +46,4 @@ class SSH2TestCase(unittest.TestCase):
 
     def _auth(self):
         return self.session.userauth_publickey_fromfile(
-            self.user, self.user_pub_key, self.user_key,
-            '')
+            self.user, self.user_key)
